@@ -14,12 +14,12 @@ schemaless_reader = _read.schemaless_reader
 read_data = _read.read_data
 is_avro = _read.is_avro
 
-READERS = _read.READERS
+_READERS = _read.READERS
 LOGICAL_READERS = _read.LOGICAL_READERS
 BLOCK_READERS = _read.BLOCK_READERS
 
 __all__ = [
     'acquaint_schema', 'reader', 'schemaless_reader', 'read_data', 'is_avro',
     'HEADER_SCHEMA', 'SYNC_SIZE', 'MAGIC', 'SchemaResolutionError',
-    'LOGICAL_READERS', 'READERS', 'BLOCK_READERS',
+    'LOGICAL_READERS', 'BLOCK_READERS',
 ]
